@@ -202,11 +202,11 @@ __END__
 
 =head1 NAME
 
-time_test.pl
+time_adapter.pl
 
 =head1 SYNOPSIS
 
-./time_test.pl
+./time_adapter.pl
 
 =head1 DESCRIPTION
 
@@ -219,7 +219,7 @@ devkitAdapter client group are assumed already set in the target broker.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
+Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
 
 =head1 SEE ALSO
 
